@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Getopt::Long::Descriptive;
 {
-  $Getopt::Long::Descriptive::VERSION = '0.093';
+  $Getopt::Long::Descriptive::VERSION = '0.094';
 }
 # ABSTRACT: Getopt::Long, but simpler and more powerful
 
@@ -367,7 +367,7 @@ Getopt::Long::Descriptive - Getopt::Long, but simpler and more powerful
 
 =head1 VERSION
 
-version 0.093
+version 0.094
 
 =head1 SYNOPSIS
 
@@ -375,8 +375,8 @@ version 0.093
 
   my ($opt, $usage) = describe_options(
     'my-program %o <some-arg>',
-    [ 'server|s=s', "the server to connect to"                  ],
-    [ 'port|p=i',   "the port to connect to", { default => 79 } ],
+    [ 'server|s=s', "the server to connect to", { required => 1  } ],
+    [ 'port|p=i',   "the port to connect to",   { default  => 79 } ],
     [],
     [ 'verbose|v',  "print extra stuff"            ],
     [ 'help',       "print usage message and exit" ],
@@ -415,8 +415,10 @@ C<describe_options>.  All GLD's exports are exported by L<Sub::Exporter>.
 
   my ($opt, $usage) = describe_options($usage_desc, @opt_spec, \%arg);
 
-This routine inspects C<@ARGV> returns the options given and a object
-for generating usage messages.
+This routine inspects C<@ARGV> for options that match the supplied spec. If all
+the options are valid then it returns the options given and an object for
+generating usage messages; if not then it dies with an explanation of what was
+wrong and a usage message.
 
 The C<$opt> object will be a dynamically-generated subclass of
 L<Getopt::Long::Descriptive::Opts>.  In brief, each of the options in
